@@ -14,7 +14,7 @@ typedef struct name_rec {
     UT_hash_handle hh;
 } name_rec;
 
-int main(int argc,char *argv[])
+int main()
 {
     name_rec *name, *names=NULL;
     char linebuf[BUFLEN];
@@ -33,7 +33,7 @@ int main(int argc,char *argv[])
         if (name == NULL) {
             exit(-1);
         }
-        strncpy(name->boy_name,linebuf,sizeof(name->boy_name));
+        strcpy(name->boy_name, linebuf);
         HASH_ADD_STR(names,boy_name,name);
     }
 
